tiled.client.xarray.DaskDatasetClient
=====================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DaskDatasetClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskDatasetClient.__init__
      ~DaskDatasetClient.download
      ~DaskDatasetClient.export
      ~DaskDatasetClient.new_variation
      ~DaskDatasetClient.read
      ~DaskDatasetClient.refresh
      ~DaskDatasetClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskDatasetClient.context
      ~DaskDatasetClient.coords
      ~DaskDatasetClient.data_vars
      ~DaskDatasetClient.formats
      ~DaskDatasetClient.item
      ~DaskDatasetClient.metadata
      ~DaskDatasetClient.offline
      ~DaskDatasetClient.path
      ~DaskDatasetClient.uri
      ~DaskDatasetClient.username
   
   